Module path

Structs

Path
A Path can be used to represent a path.
PathBuf
A path buffer that can be used to build paths.

Type Aliases

FullPath
A full path joined which can either be str or String.
Part
A part of a path which can either be str or String.