Struct Path

pub struct Path<'a, 'b> { /* private fields */ }
A Path can be used to represent a path.

A path is a sequence of parts that are joined together by a joiner. The joiner is a string that is used to split the path into parts and into a PathBuf.

Example

use postcard_bindgen_core::path::Path;

let path = Path::new("foo/bar/baz", "/");

assert_eq!(path.parts().collect::<Vec<&str>>(), vec!["foo", "bar", "baz"]);

Implementations

Source

impl<'a, 'b> Path<'a, 'b>

pub fn new( path: impl Into<FullPath<'a>>, joiner: impl Into<Cow<'b, str>>, ) -> Self

Create a new path from something which can be converted into a FullPath and a joiner which is either str or String.

pub fn parts(&self) -> impl Iterator<Item = &str>

Gives an iterator over the parts of the path.

pub fn flatten(&mut self)

Flatten the path to the root by simply removing all parts.

pub fn into_buf(self) -> PathBuf<'a>

Convert the path into a PathBuf by consuming the path and splitting it into parts.

pub fn is_empty(&self) -> bool

Check if the path is empty.

pub fn into_owned(self) -> Path<'static, 'static>

Convert the path into an owned path by consuming the path.