Struct PathBuf

pub struct PathBuf<'a> { /* private fields */ }
A path buffer that can be used to build paths.

The difference between a PathBuf and a Path is that a PathBuf is mutable and can be modified, while a Path is immutable and is joined into one but knows how to split it into parts.

Example

use postcard_bindgen_core::path::PathBuf;

let mut path = PathBuf::new();

assert!(path.is_empty());

path.push("foo");
path.push("bar");
path.push("baz");

assert!(!path.is_empty());
assert_eq!(path.parts().map(|p| p.as_ref()).collect::<Vec<&str>>(), vec!["foo", "bar", "baz"]);

Implementations

Source

impl<'a> PathBuf<'a>

pub fn new() -> Self

Create a new empty path buffer.

pub fn join(self, joiner: impl Into<Part<'a>>) -> Self

Join a part into the path buffer by consuming the PathBuf.

This allows to chain calls to join parts into the path buffer.

Example
use postcard_bindgen_core::path::PathBuf;

let path = PathBuf::new().join("foo").join("bar").join("baz");

assert_eq!(path.parts().map(|p| p.as_ref()).collect::<Vec<&str>>(), vec!["foo", "bar", "baz"]);
pub fn push(&mut self, part: impl Into<Part<'a>>)

Push a part to the end of the path buffer.

pub fn push_front(&mut self, part: impl Into<Part<'a>>)

Push a part to the front of the path buffer.

pub fn pop_front(&mut self)

Pop a part from the end of the path buffer.

pub fn parts(&self) -> impl Iterator<Item = &Part<'a>>

Gives an iterator over the parts of the path buffer.

pub fn is_empty(&self) -> bool

Check if the path buffer is empty.

pub fn into_path<'b>(self, joiner: impl Into<Part<'b>>) -> Path<'a, 'b>

Convert the path buffer into a Path by consuming the path buffer.

pub fn flatten(&mut self)

Flatten the path to the root by simply removing all parts.

pub fn into_owned(self) -> PathBuf<'static>

Convert the path buffer into an owned path buffer by consuming the path buffer.