Struct ContainerCollection

pub struct ContainerCollection(/* private fields */);
Wraps a tree of nodes that contain the bindings.

Can be build from a BindingsRegistry by calling BindingsRegistry::into_entries().

Implementations

Source

impl ContainerCollection

pub fn flatten(&mut self)

Removes all module nodes and moves their children to the root node.

Can be used to remove the module hierarchy.

pub fn all_containers(&self) -> impl Iterator<Item = Container> + Clone + '_

pub fn containers_per_module(&self) -> (Vec<Container>, Vec<Module<'_>>)