Struct postcard_bindgen_core::ExportStrings
source · Expand description
Helper struct to pass the generated language strings to an export function.
Fields
js_file: Stringts_file: StringHelper struct to pass the generated language strings to an export function.
js_file: Stringts_file: String