pub struct Path<'a, 'b> { /* private fields */ }Expand description
A Path can be used to represent a path.
A path is a sequence of parts that are joined together by a joiner. The joiner is a string that is used to split the path into parts and into a PathBuf.
Example
use postcard_bindgen_core::path::Path;
let path = Path::new("foo/bar/baz", "/");
assert_eq!(path.parts().collect::<Vec<&str>>(), vec!["foo", "bar", "baz"]);Implementations
Sourceimpl<'a, 'b> Path<'a, 'b>
impl<'a, 'b> Path<'a, 'b>
Sourcepub fn parts(&self) -> impl Iterator<Item = &str>
pub fn parts(&self) -> impl Iterator<Item = &str>
Gives an iterator over the parts of the path.
Sourcepub fn into_buf(self) -> PathBuf<'a>
pub fn into_buf(self) -> PathBuf<'a>
Convert the path into a PathBuf by consuming the path and splitting it into parts.
Sourcepub fn into_owned(self) -> Path<'static, 'static>
pub fn into_owned(self) -> Path<'static, 'static>
Convert the path into an owned path by consuming the path.